nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Div

Struct Div 

#[repr(transparent)]
pub struct Div(pub u32);
SPI clock Divider

Tuple Fields

0: u32

Implementations

Source

impl Div

pub const fn divval(&self) -> u16

Rate divider value. Specifies how the Flexcomm clock (FCLK) is divided to produce the SPI clock rate in master mode. DIVVAL is -1 encoded such that the value 0 results in FCLK/1, the value 1 results in FCLK/2, up to the maximum possible divide value of 0xFFFF, which results in FCLK/65536.

pub const fn set_divval(&mut self, val: u16)

Rate divider value. Specifies how the Flexcomm clock (FCLK) is divided to produce the SPI clock rate in master mode. DIVVAL is -1 encoded such that the value 0 results in FCLK/1, the value 1 results in FCLK/2, up to the maximum possible divide value of 0xFFFF, which results in FCLK/65536.