#[repr(transparent)]pub struct Intenset(pub u32);Expand description
SPI Interrupt Enable read and Set. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.
Tuple Fields
0: u32Implementations
Sourceimpl Intenset
impl Intenset
Sourcepub const fn ssaen(&self) -> bool
pub const fn ssaen(&self) -> bool
Slave select assert interrupt enable. Determines whether an interrupt occurs when the Slave Select is asserted.
Sourcepub const fn set_ssaen(&mut self, val: bool)
pub const fn set_ssaen(&mut self, val: bool)
Slave select assert interrupt enable. Determines whether an interrupt occurs when the Slave Select is asserted.
Sourcepub const fn ssden(&self) -> bool
pub const fn ssden(&self) -> bool
Slave select deassert interrupt enable. Determines whether an interrupt occurs when the Slave Select is deasserted.
Sourcepub const fn set_ssden(&mut self, val: bool)
pub const fn set_ssden(&mut self, val: bool)
Slave select deassert interrupt enable. Determines whether an interrupt occurs when the Slave Select is deasserted.
Sourcepub const fn set_mstidleen(&mut self, val: bool)
pub const fn set_mstidleen(&mut self, val: bool)
Master idle interrupt enable.